@@ -11,13 +11,15 @@ import typing_extensions
 import aws_cdk.aws_ec2._jsii
 import aws_cdk.aws_iam._jsii
 import aws_cdk.aws_kms._jsii
+import aws_cdk.aws_lambda._jsii
 import aws_cdk.aws_s3._jsii
 import aws_cdk.aws_secretsmanager._jsii
 import aws_cdk.core._jsii
+import aws_cdk.custom_resources._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "@aws-cdk/aws-redshift", "1.116.0", __name__[0:-6], "aws-redshift@1.116.0.jsii.tgz"
+    "@aws-cdk/aws-redshift", "1.126.0", __name__[0:-6], "aws-redshift@1.126.0.jsii.tgz"
 )
 
 __all__ = [
